!=========================================================================
! Copyright (C) GemTalk Systems 1986-2017.  All Rights Reserved.
!
! $Id: nameless.gs 42264 2017-07-28 05:24:38Z lalmarod $
!
! Description - Create the Nameless user account.
! 
! Repository conversion - this file is used
!
!=======================================================================

! login as SystemUser
set user SystemUser pass swordfish
iferror exit
login 
iferror

expectvalue %String
run
   "Expect a four element Array of user IDs: SystemUser, DataCurator,
    GcUser and Nameless "
| nameless newUser userGlbl seg8 report lf |

nameless := AllUsers detect: [ :x | x userId = 'Nameless' ] ifNone: [nil].
seg8 := (Globals at:#SystemRepository) at: 8 .
report := String new .
lf := Character lf .
nameless ~~ nil ifTrue: [ | defSeg |
    "Nameless already exists. Set its password."
    nameless password: 'swordfish'.
    defSeg := nameless defaultObjectSecurityPolicy .
    defSeg == seg8 ifFalse:[  
      nameless defaultObjectSecurityPolicy: seg8 .
    ].
    report addAll: 'Nameless already exists ' ; add: lf .
    seg8 isInvariant ifFalse:[
      seg8 owner: nameless  ;
          ownerAuthorization: #write ;
          worldAuthorization: #read .  
    ] ifTrue:[
      report addAll:'seg8 isInvariant' ; add: lf .
    ].
] ifFalse: [
    "Create a new Nameless user account"
    newUser := UserProfile newWithUserId: 'Nameless'
                         password: #swordfish
                         defaultObjectSecurityPolicy: seg8
                         privileges: #()
                         inGroups: #() .

    seg8 owner: newUser ;
       ownerAuthorization: #write;
       worldAuthorization: #write .

    " AllUsers add: newUser. --- no longer needed "

    " Put Nameless in SystemUser's UserGlobals "
    UserGlobals at: #Nameless put: newUser.

    " Put Nameless in DataCurator's UserGlobals"
    ((AllUsers userWithId: #DataCurator) resolveSymbol: #UserGlobals) value at: 
       #Nameless put: newUser.

    " Put Nameless in its own UserGlobals"
    userGlbl := (newUser resolveSymbol: #UserGlobals) value.
    userGlbl at: #Nameless put: newUser.

    report addAll: 'created Nameless' ; add: lf .
].
^ report
%

! =====================================================================
! adjust existing UserProfiles to grant new inverse privileges
run
| priv setBlk clearBlk inversePrivs newPrivs LF |
System myUserProfile userId = 'SystemUser' ifFalse:[ nil error:'wrong user'].
LF := Character lf .
newPrivs := #( #SessionPriority ) .
inversePrivs := #( #NoPerformOnServer #NoUserAction
             #NoGsFileOnServer #NoGsFileOnClient ) .
setBlk := [ :aUp :anArray :name | 
  anArray do:[ :aPriv | aUp addPrivilege: aPriv ] .
  GsFile gciLogClient:'set ', name , ' priv bits for ' , aUp userId , LF .
].
clearBlk := [ :aUp :anArray :name | 
  anArray do:[ :aPriv | aUp deletePrivilege: aPriv] .
  GsFile gciLogClient:'cleared ', name, ' priv bits for ' , aUp userId , LF .
].
AllUsers do:[ :aUp | | uid |
  uid := aUp userId .
  (UserProfile isSpecialUserId: uid) ifTrue:[
    (uid = 'SystemUser' or:[ uid = 'DataCurator']) ifTrue:[
      clearBlk value: aUp value: inversePrivs value: 'inverse' .
      setBlk value: aUp value: newPrivs value: 'new' .
      uid = 'DataCurator' ifTrue:[ aUp deletePrivilege: #CompilePrimitives]. 
      uid = 'SystemUser' ifTrue:[ aUp addPrivilege: #CompilePrimitives ].
    ] ifFalse:[  "gcuser, symboluser, nameless"
      setBlk value: aUp value: inversePrivs value: 'inverse' . 
      aUp deletePrivilege: #CompilePrimitives .
    ].
  ] ifFalse:[
    "preexisting customer user profiles not affected. 
     If customers have blindly set all priv bits those Up's need adjustment.
    "
  ].
]. 
^ true
%
level 1
expectvalue %Array
run
(AllUsers userWithId:'SystemUser') privileges
%
expectvalue %Array
run
(AllUsers userWithId:'DataCurator') privileges
%
expectvalue %Array
run
(AllUsers userWithId:'GcUser') privileges
%
expectvalue %Array
run
(AllUsers userWithId:'SymbolUser') privileges
%
expectvalue %Array
run
(AllUsers userWithId:'Nameless') privileges
%
level 0

commit

logout

